# Examples

The next pages contains a few simple examples of how to use Pykka.

- [Basic actor](basic.md) - a simple example of a message-passing actor.
- [Actor with proxy](proxy.md) - an example of an actor with a proxy.
- [Cooperating actors](cooperation.md) - an example of two actors cooperating.
- [Worker pool](worker-pool.md) - an example using a pool of actors to split up work.
- [Mopidy music server](mopidy.md) - a real-life example of using Pykka.

All of the examples can also be found in the
[`examples/` directory on GitHub](https://github.com/jodal/pykka/tree/main/examples).
